@@ -85,12 +85,13 @@ class Cycletools:
     Lampen synchron blinken zu lassen.
     """
 
-    __slots__ = "__cycle", "__cycletime", "__ucycle", \
-                "__dict_ton", "__dict_tof", "__dict_tp", "first", "last", \
+    __slots__ = "__cycle", "__cycletime", "__ucycle", "__dict_ton", \
+                "__dict_tof", "__dict_tp", "_start_timer", "core", "device", \
+                "first", "io", "last", "var", \
                 "flag1c", "flag5c", "flag10c", "flag15c", "flag20c", \
-                "flank5c", "flank10c", "flank15c", "flank20c", "var"
+                "flank5c", "flank10c", "flank15c", "flank20c"
 
-    def __init__(self, cycletime):
+    def __init__(self, cycletime, revpi_object):
         """Init Cycletools class."""
         self.__cycle = 0
         self.__cycletime = cycletime
@@ -98,6 +99,12 @@ class Cycletools:
         self.__dict_ton = {}
         self.__dict_tof = {}
         self.__dict_tp = {}
+        self._start_timer = 0.0
+
+        # Access to core and io
+        self.core = revpi_object.core
+        self.device = revpi_object.device
+        self.io = revpi_object.io
 
         # Taktmerker
         self.first = True
@@ -298,6 +305,17 @@ class Cycletools:
         else:
             self.__dict_tp[name][1] = True
 
+    @property
+    def runtime(self) -> float:
+        """
+        Runtime im milliseconds of cycle function till now.
+
+        This property will return the actual runtime of the function. So on the
+        beginning of your function it will be about 0 and will rise during
+        the runtime to the max in the last line of your function.
+        """
+        return (default_timer() - self._start_timer) * 1000
+
 
 class ProcimgWriter(Thread):
     """
@@ -339,9 +357,9 @@ class ProcimgWriter(Thread):
 
             if io_event._bitshift:
                 boolcp = dev._ba_datacp[io_event._slc_address.start] \
-                         & io_event._bitshift
+                    & io_event._bitshift
                 boolor = dev._ba_devdata[io_event._slc_address.start] \
-                         & io_event._bitshift
+                    & io_event._bitshift
 
                 if boolor == boolcp:
                     continue
@@ -458,9 +476,11 @@ class ProcimgWriter(Thread):
         self._adjwait = self._refresh
 
         mrk_warn = True
+        mrk_dt = default_timer()
 
+        bytesbuff = bytearray(self._modio._length)
         while not self._work.is_set():
-            ot = default_timer()
+            ot = mrk_dt
 
             # Lockobjekt holen und Fehler werfen, wenn nicht schnell genug
             if not self.lck_refresh.acquire(timeout=self._adjwait):
@@ -474,7 +494,7 @@ class ProcimgWriter(Thread):
 
             try:
                 fh.seek(0)
-                bytesbuff = bytearray(fh.read(self._modio._length))
+                fh.readinto(bytesbuff)
 
                 if self._modio._monitoring or self._modio._direct_output:
                     # Inputs und Outputs in Puffer
@@ -550,7 +570,8 @@ class ProcimgWriter(Thread):
                 self._work.wait(self._adjwait)
 
             # Wartezeit anpassen um echte self._refresh zu erreichen
-            if default_timer() - ot >= self._refresh:
+            mrk_dt = default_timer()
+            if mrk_dt - ot >= self._refresh:
                 self._adjwait -= 0.001
                 if self._adjwait < 0:
                     warnings.warn(
