@@ -248,6 +248,12 @@ class RevPiModIO(object):
                         self, device, simulator=self._simulator
                     )
                     self.core = dev_new
+                elif pt == 104:
+                    # RevPi Compact
+                    dev_new = devicemodule.Compact(
+                        self, device, simulator=self._simulator
+                    )
+                    self.core = dev_new
                 else:
                     # Base immer als Fallback verwenden
                     dev_new = devicemodule.Base(
@@ -324,7 +330,8 @@ class RevPiModIO(object):
             self.syncoutputs()
 
         # Für RS485 errors am core defaults laden sollte procimg NULL sein
-        if not (self.core is None or self._monitoring or self._simulator):
+        if isinstance(self.core, devicemodule.Core) and \
+                not (self._monitoring or self._simulator):
             if self.core._slc_errorlimit1 is not None:
                 io = self.io[
                     self.core.offset + self.core._slc_errorlimit1.start
@@ -727,9 +734,9 @@ class RevPiModIO(object):
         # Cycleloop starten
         self._exit.clear()
         self._looprunning = True
-        cycleinfo = helpermodule.Cycletools(self._imgwriter.refresh)
-        e = None
-        ec = None
+        cycleinfo = helpermodule.Cycletools(self._imgwriter.refresh, self)
+        e = None  # Exception
+        ec = None  # Return value of cycle_function
         try:
             while ec is None and not cycleinfo.last:
                 # Auf neue Daten warten und nur ausführen wenn set()
@@ -745,8 +752,11 @@ class RevPiModIO(object):
                 # Vor Aufruf der Funktion autorefresh sperren
                 self._imgwriter.lck_refresh.acquire()
 
-                # Funktion aufrufen und auswerten
+                # Vorbereitung für cycleinfo
+                cycleinfo._start_timer = default_timer()
                 cycleinfo.last = self._exit.is_set()
+
+                # Funktion aufrufen und auswerten
                 ec = func(cycleinfo)
                 cycleinfo._docycle()
 
@@ -1326,6 +1336,29 @@ class RevPiModIODriver(RevPiModIOSelected):
         )
 
 
+def run_plc(func, cycletime=50, replace_io_file=None):
+    """
+    Run Revoluton Pi as real plc with cycle loop and exclusive IO access.
+
+    This function is just a shortcut to run the module in cycle loop mode and
+    handle the program exit signal. You will access the .io, .core, .device
+    via the cycletools in your cycle function.
+
+    Shortcut vor this source code:
+        rpi = RevPiModIO(autorefresh=True, replace_io_file=replace_io_file)
+        rpi.handlesignalend()
+        return rpi.cycleloop(func, cycletime)
+
+    :param func: Function to run every set milliseconds
+    :param cycletime: Cycle time in milliseconds
+    :param replace_io_file: Load replace IO configuration from file
+    :return: None or the return value of the cycle function
+    """
+    rpi = RevPiModIO(autorefresh=True, replace_io_file=replace_io_file)
+    rpi.handlesignalend()
+    return rpi.cycleloop(func, cycletime)
+
+
 # Nachträglicher Import
 from . import app as appmodule
 from . import device as devicemodule
